@@ -151,7 +151,7 @@ GVWebPage::isOnline ()
     return nwCfg->isOnline ();
 #else
     // In Symbian with no signing, pretend we're always online.
-    // This is because we don't want to sign
+    // This is because we don't want to sign... yet
     return true;
 #endif
 }//GVWebPage::isOnline
@@ -1449,6 +1449,16 @@ GVWebPage::startTimerForReply (QNetworkReply *reply)
 
 void
 GVWebPage::onNwCfgChanged (const QNetworkConfiguration & /*config*/)
+{
+    QMutexLocker locker(&mutex);
+    if (NULL != nwCfg) {
+        qDebug ("Scheduled deletion of nwCfg");
+        QTimer::singleShot (30 * 1000, this, SLOT(onDelayedNwCfgDelete()));
+    }
+}//GVWebPage::onNwCfgChanged
+
+void
+GVWebPage::onDelayedNwCfgDelete ()
 {
     QMutexLocker locker(&mutex);
     if (NULL != nwCfg) {
@@ -1456,4 +1466,4 @@ GVWebPage::onNwCfgChanged (const QNetworkConfiguration & /*config*/)
         nwCfg = NULL;
         qDebug ("Deleted nwCfg");
     }
-}//GVWebPage::onNwCfgChanged
+}//GVWebPage::onDelayedNwCfgDelete
